% This is a test script that runs image compression on the image file
% 'tank.tiff'. It iterates through a loop, varying the values of the mask
% matrix that's used to compress the image. In the first iteration, the
% mask has only a single one at (1,1). This gets increased until it has 
% 36 ones and 28 zeros. 
% Every loop, it computes the L2-norm and the compressed size. At the end,
% it draws plots for these values

% Defining constants and variables used throughout the script here
size = 8;
BYTES_PER_KB = 1024;
range = 1:size;
digits_preserved = [];
errors = [];
file_sizes = [];

% Iterate through all the different mask sizes, compressing the image and
% computing L2-norm and compressed size
for n=range
   mask = [ones(1, n) zeros(1, size-n)
        ones(1, max(0, n-1)) zeros(1, min(size-n+1, size))
        ones(1, max(0, n-2)) zeros(1, min(size-n+2, size))
        ones(1, max(0, n-3)) zeros(1, min(size-n+3, size))
        ones(1, max(0, n-4)) zeros(1, min(size-n+4, size))
        ones(1, max(0, n-5)) zeros(1, min(size-n+5, size))
        ones(1, max(0, n-6)) zeros(1, min(size-n+6, size))
        ones(1, max(0, n-7)) zeros(1, min(size-n+7, size))];

   [I, DCT, rDCT, I2] = compressimage('tank.tiff', mask);
   
   error = geterror(I, I2);
   errors = [errors error]; 
   
   result_size = nnz(rDCT)/BYTES_PER_KB;
   file_sizes = [file_sizes result_size];
   
   num_digits_preserved = 0;
   for i=1:n
       num_digits_preserved = num_digits_preserved + i;
   end
   digits_preserved = [digits_preserved num_digits_preserved];


   figure, imshow(I2)
end

x_axis_string = strcat('Number of values preserved out of ', num2str(size^2));
% Draw plots of L2-norm on regular and semilogy plots
figure, plot(digits_preserved, errors, '+-')
xlabel(x_axis_string)
ylabel('L2-norm')

figure, semilogy(digits_preserved, errors, '+-')
xlabel(x_axis_string)
ylabel('L2-norm')

% Draw plot of file sizes, with a line included for the original size
figure, plot (digits_preserved, file_sizes, '+-')
xlabel(x_axis_string)
ylabel('File size (KB)')
hold on
original_size = nnz(DCT)/BYTES_PER_KB;
plot(digits_preserved, ones(1, size)*original_size, 'g');